@@ -31,6 +31,8 @@ int do_PerflibNetFramework(int update_every, usec_t dt);
 int do_PerflibAD(int update_every, usec_t dt);
 int do_PerflibADCS(int update_every, usec_t dt);
 int do_PerflibADFS(int update_every, usec_t dt);
+int do_PerflibHyperV(int update_every, usec_t dt);
+int do_PerflibServices(int update_every, usec_t dt);
 
 enum PERFLIB_PRIO {
     PRIO_WEBSITE_IIS_REQUESTS_RATE = 21000, // PRIO selected, because APPS is using 20YYY
@@ -132,6 +134,8 @@ enum PERFLIB_PRIO {
     PRIO_NETFRAMEWORK_CLR_LOCKS_AND_THREADS_RECOGNIZED_THREADS,
     PRIO_NETFRAMEWORK_CLR_LOCKS_AND_THREADS_CONTENTIONS,
 
+    PRIO_SERVICE_STATE,
+
     PRIO_AD_OPERATIONS_TOTAL,
     PRIO_AD_DIROPERATIONS_TOTAL,
     PRIO_AD_CACHE_LOOKUP_TOTAL,
@@ -194,6 +198,4 @@ enum PERFLIB_PRIO {
     PRIO_ADFS_WSFED_TOKEN_REQUESTS
 };
 
-int do_PerflibHyperV(int update_every, usec_t dt);
-
 #endif //NETDATA_WINDOWS_PLUGIN_H
