@@ -7,8 +7,10 @@
 
 void netdata_conf_section_global(void);
 void netdata_conf_section_global_run_as_user(const char **user);
+void netdata_conf_section_global_hostname(void);
 
 size_t netdata_conf_cpus(void);
+void libuv_initialize(void);
 
 void netdata_conf_glibc_malloc_initialize(size_t wanted_arenas, size_t trim_threshold);
 
