@@ -1117,6 +1117,10 @@ static void worker_utilization_charts_callback(void *ptr
         wu->memory_calls[i] += memory_calls[i];
 }
 
+static void spinlocks_free_callback(Word_t key __maybe_unused, struct worker_spinlocks *wusp, void *data __maybe_unused) {
+    freez(wusp);
+}
+
 void pulse_workers_cleanup(void) {
     int i, j;
     for(i = 0; all_workers_utilization[i].name ;i++) {
@@ -1135,6 +1139,9 @@ void pulse_workers_cleanup(void) {
             wu->per_job_type[j].units = NULL;
         }
 
+        // Free the spinlocks Judy array for this worker
+        SPINLOCKS_FREE(&wu->spinlocks, spinlocks_free_callback, NULL);
+
         // mark all threads as not enabled
         struct worker_thread *t;
         for(t = wu->threads; t ; t = t->next)
@@ -1143,6 +1150,9 @@ void pulse_workers_cleanup(void) {
         // let the cleanup job free them
         workers_threads_cleanup(wu);
     }
+    
+    // Clean up the global spinlocks array
+    SPINLOCKS_FREE(&ALL_SPINLOCKS, spinlocks_free_callback, NULL);
 }
 
 void pulse_workers_do(bool extended) {
