@@ -20,6 +20,8 @@
 #include "pdc.h"
 #include "page.h"
 
+#include "daemon/protected-access.h"
+
 extern unsigned rrdeng_pages_per_extent;
 
 /* Forward declarations */
@@ -546,7 +548,7 @@ static inline int journal_metric_uuid_compare(const void *key, const void *metri
 }
 
 // --------------------------------------------------------------------------------------------------------------------
-uint64_t rrdeng_get_used_disk_space(struct rrdengine_instance *ctx);
+uint64_t rrdeng_get_used_disk_space(struct rrdengine_instance *ctx, bool having_lock);
 void rrdeng_calculate_tier_disk_space_percentage(void);
 uint64_t rrdeng_get_directory_free_bytes_space(struct rrdengine_instance *ctx);
 void dbengine_shutdown();
