@@ -99,7 +99,7 @@ void rrdhost_system_info_to_node_info(struct rrdhost_system_info *system_info, s
 
 void rrdhost_system_info_to_streaming_function_array(BUFFER *wb, struct rrdhost_system_info *system_info);
 
-void get_daemon_status_fields_from_system_info(DAEMON_STATUS_FILE *ds);
+bool get_daemon_status_fields_from_system_info(DAEMON_STATUS_FILE *ds);
 void rrdhost_system_info_swap(struct rrdhost_system_info *a, struct rrdhost_system_info *b);
 
 #endif //NETDATA_RRDHOST_SYSTEM_INFO_H
