@@ -74,10 +74,10 @@ static struct aclk_database_cmd aclk_database_deq_cmd(void)
     return ret;
 }
 
-static void aclk_database_enq_cmd(struct aclk_database_cmd *cmd)
+static bool aclk_database_enq_cmd(struct aclk_database_cmd *cmd)
 {
-    if(unlikely(!aclk_sync_config.initialized))
-        return;
+    if(unlikely(!__atomic_load_n(&aclk_sync_config.initialized, __ATOMIC_RELAXED)))
+        return false;
 
     struct aclk_database_cmd *t = aral_mallocz(aclk_sync_config.ar);
     *t = *cmd;
@@ -88,6 +88,7 @@ static void aclk_database_enq_cmd(struct aclk_database_cmd *cmd)
     spinlock_unlock(&aclk_sync_config.cmd_queue_lock);
 
     (void) uv_async_send(&aclk_sync_config.async);
+    return true;
 }
 
 enum {
@@ -358,13 +359,15 @@ static void aclk_run_query(struct aclk_sync_config_s *config, aclk_query_t query
     }
 
     bool ok_to_send = true;
+    mqtt_wss_client client = __atomic_load_n(&config->client, __ATOMIC_RELAXED);
 
     switch (query->type) {
 
 // Incoming : cloud -> agent
         case HTTP_API_V2:
             worker_is_busy(UV_EVENT_ACLK_QUERY_EXECUTE);
-            http_api_v2(config->client, query);
+            if (client)
+                http_api_v2(client, query);
             ok_to_send = false;
             break;
         case CTX_CHECKPOINT:;
@@ -429,8 +432,14 @@ static void aclk_run_query(struct aclk_sync_config_s *config, aclk_query_t query
             break;
     }
 
-    if (ok_to_send)
-        send_bin_msg(config->client, query);
+    if (ok_to_send) {
+        if (client)
+            send_bin_msg(client, query);
+        else {
+            freez(query->data.bin_payload.payload);
+            nd_log_daemon(NDLP_ERR, "No client to send message %u", query->type);
+        }
+    }
 
     aclk_query_free(query);
 }
@@ -497,6 +506,11 @@ struct worker_data {
     struct aclk_sync_config_s *config;
 };
 
+struct notify_timer_cb_data {
+    void *payload;
+    struct completion *completion;
+};
+
 static void after_do_unregister_node(uv_work_t *req, int status __maybe_unused)
 {
     struct worker_data *data = req->data;
@@ -516,22 +530,25 @@ static void do_unregister_node(uv_work_t *req)
     worker_is_idle();
 }
 
-static void node_update_timer_cb(uv_timer_t *handle)
+static void notify_timer_close_callback(uv_handle_t *handle)
 {
-    struct aclk_sync_cfg_t *ahc = handle->data;
-    RRDHOST *host = ahc->host;
-
-    if(!host || aclk_host_state_update_auto(host))
-        uv_timer_stop(&ahc->timer);
+    struct notify_timer_cb_data *data = handle->data;
+    if (data->completion) {
+        completion_mark_complete(data->completion);
+    }
+    freez(data);
 }
 
-static void close_callback(uv_handle_t *handle, void *data __maybe_unused)
+static void node_update_timer_cb(uv_timer_t *handle)
 {
-    if (handle->type == UV_TIMER) {
-        uv_timer_stop((uv_timer_t *)handle);
-    }
+    struct aclk_sync_cfg_t *aclk_host_config = handle->data;
+    if (unlikely(!aclk_host_config))
+        return;
 
-    uv_close(handle, NULL);  // Automatically close and free the handle
+    RRDHOST *host = aclk_host_config->host;
+
+    if(!host || aclk_host_state_update_auto(host))
+        uv_timer_stop(&aclk_host_config->timer);
 }
 
 static void after_start_alert_push(uv_work_t *req, int status __maybe_unused)
@@ -616,8 +633,11 @@ static void aclk_synchronization_event_loop(void *arg)
     worker_register_job_name(ACLK_QUERY_EXECUTE_SYNC,           "aclk query execute sync");
     worker_register_job_name(ACLK_QUERY_BATCH_EXECUTE,          "aclk batch execute");
     worker_register_job_name(ACLK_QUERY_BATCH_ADD,              "aclk batch add");
-    worker_register_job_name(ACLK_MQTT_WSS_CLIENT,              "config mqtt client");
+    worker_register_job_name(ACLK_MQTT_WSS_CLIENT_SET,          "config mqtt client");
+    worker_register_job_name(ACLK_MQTT_WSS_CLIENT_RESET,        "reset mqtt client");
     worker_register_job_name(ACLK_DATABASE_NODE_UNREGISTER,     "unregister node");
+    worker_register_job_name(ACLK_CANCEL_NODE_UPDATE_TIMER,     "cancel node update timer");
+    worker_register_job_name(ACLK_QUEUE_NODE_INFO,     "queue node info");
 
     uv_loop_t *loop = &config->loop;
     fatal_assert(0 == uv_loop_init(loop));
@@ -637,6 +657,7 @@ static void aclk_synchronization_event_loop(void *arg)
     netdata_log_info("Starting ACLK synchronization thread with %d parallel query threads", query_thread_count);
 
     struct worker_data *data;
+    struct notify_timer_cb_data *timer_cb_data;
     aclk_query_t query;
 
     // This holds queries that need to be executed one by one
@@ -656,6 +677,8 @@ static void aclk_synchronization_event_loop(void *arg)
 
     while (likely(ACLK_SYNC_SHOULD_BE_RUNNING)) {
         enum aclk_database_opcode opcode;
+        RRDHOST *host;
+        struct aclk_sync_cfg_t *aclk_host_config;
         worker_is_idle();
         uv_run(loop, UV_RUN_DEFAULT);
 
@@ -692,30 +715,30 @@ static void aclk_synchronization_event_loop(void *arg)
                     /* the command queue was empty, do nothing */
                     break;
                     // NODE STATE
-                case ACLK_DATABASE_NODE_STATE:;
-                    RRDHOST *host = cmd.param[0];
-                    struct aclk_sync_cfg_t *ahc = host->aclk_config;
-                    if (unlikely(!ahc)) {
+                case ACLK_DATABASE_NODE_STATE:
+                    host = cmd.param[0];
+                    aclk_host_config = host->aclk_host_config;
+                    if (unlikely(!aclk_host_config)) {
                         create_aclk_config(host, &host->host_id.uuid, &host->node_id.uuid);
-                        ahc = host->aclk_config;
+                        aclk_host_config = host->aclk_host_config;
                     }
 
-                    if (ahc) {
+                    if (aclk_host_config) {
                         uint64_t schedule_time = (uint64_t)(uintptr_t)cmd.param[1];
-                        if (!ahc->timer_initialized) {
-                            int rc = uv_timer_init(loop, &ahc->timer);
+                        if (!aclk_host_config->timer_initialized) {
+                            int rc = uv_timer_init(loop, &aclk_host_config->timer);
                             if (!rc) {
-                                ahc->timer_initialized = true;
-                                ahc->timer.data = ahc;
+                                aclk_host_config->timer_initialized = true;
+                                aclk_host_config->timer.data = aclk_host_config;
                             }
                         }
 
-                        if (ahc->timer_initialized) {
-                            if (uv_is_active((uv_handle_t *)&ahc->timer))
-                                uv_timer_stop(&ahc->timer);
+                        if (aclk_host_config->timer_initialized) {
+                            if (uv_is_active((uv_handle_t *)&aclk_host_config->timer))
+                                uv_timer_stop(&aclk_host_config->timer);
 
-                            ahc->timer.data = ahc;
-                            int rc = uv_timer_start(&ahc->timer, node_update_timer_cb, schedule_time, 5000);
+                            aclk_host_config->timer.data = aclk_host_config;
+                            int rc = uv_timer_start(&aclk_host_config->timer, node_update_timer_cb, schedule_time, 5000);
                             if (!rc)
                                 break; // Timer started, exit
                         }
@@ -724,6 +747,34 @@ static void aclk_synchronization_event_loop(void *arg)
                     // This is fallback if timer fails
                     aclk_host_state_update_auto(host);
                     break;
+                case ACLK_QUEUE_NODE_INFO:
+                    host = cmd.param[0];
+                    bool immediate = (bool)(uintptr_t)cmd.param[1];
+                    aclk_host_config = host->aclk_host_config;
+                    if (unlikely(!aclk_host_config)) {
+                        create_aclk_config(host, &host->host_id.uuid, &host->node_id.uuid);
+                        aclk_host_config = host->aclk_host_config;
+                    }
+                    aclk_host_config->node_info_send_time = (host == localhost ||(void *)(uintptr_t) immediate) ? 1 : now_realtime_sec();
+                    break;
+                case ACLK_CANCEL_NODE_UPDATE_TIMER:
+                    host = cmd.param[0];
+                    struct completion *compl = cmd.param[1];
+                    aclk_host_config = host->aclk_host_config;
+                    if (!aclk_host_config || !aclk_host_config->timer_initialized) {
+                        completion_mark_complete(compl);
+                        break;
+                    }
+                    if (uv_is_active((uv_handle_t *)&aclk_host_config->timer))
+                        uv_timer_stop(&aclk_host_config->timer);
+
+                    aclk_host_config->timer_initialized = false;
+                    timer_cb_data = mallocz(sizeof(*timer_cb_data));
+                    timer_cb_data->payload = host;
+                    timer_cb_data->completion = compl;
+                    aclk_host_config->timer.data = timer_cb_data;
+                    uv_close((uv_handle_t *)&aclk_host_config->timer, notify_timer_close_callback);
+                    break;
 
                 case ACLK_DATABASE_NODE_UNREGISTER:
                     data = mallocz(sizeof(*data));
@@ -736,7 +787,6 @@ static void aclk_synchronization_event_loop(void *arg)
                         freez(data);
                     }
                     break;
-                    // ALERTS
                 case ACLK_DATABASE_PUSH_ALERT_CONFIG:
                     aclk_push_alert_config_event(cmd.param[0], cmd.param[1]);
                     break;
@@ -756,10 +806,14 @@ static void aclk_synchronization_event_loop(void *arg)
                         config->alert_push_running = false;
                     }
                     break;
-                case ACLK_MQTT_WSS_CLIENT:
+                case ACLK_MQTT_WSS_CLIENT_SET:
                     config->client = (mqtt_wss_client)cmd.param[0];
                     break;
-
+                case ACLK_MQTT_WSS_CLIENT_RESET:
+                    __atomic_store_n(&config->client, NULL, __ATOMIC_RELEASE);
+                    struct completion *comp = cmd.param[0];
+                    completion_mark_complete(comp);
+                    break;
                 case ACLK_QUERY_EXECUTE:
                     query = (aclk_query_t)cmd.param[0];
 
@@ -878,9 +932,7 @@ static void aclk_synchronization_event_loop(void *arg)
         uv_close((uv_handle_t *)&config->timer_req, NULL);
 
     uv_close((uv_handle_t *)&config->async, NULL);
-    uv_run(loop, UV_RUN_NOWAIT);
-
-    uv_walk(loop, (uv_walk_cb) close_callback, NULL);
+    uv_walk(loop, libuv_close_callback, notify_timer_close_callback);
     uv_run(loop, UV_RUN_NOWAIT);
 
     (void) uv_loop_close(loop);
@@ -927,34 +979,30 @@ static void aclk_initialize_event_loop(void)
 
 // -------------------------------------------------------------
 
-void create_aclk_config(RRDHOST *host __maybe_unused, nd_uuid_t *host_uuid __maybe_unused, nd_uuid_t *node_id __maybe_unused)
+void create_aclk_config(RRDHOST *host, nd_uuid_t *host_uuid __maybe_unused, nd_uuid_t *node_id __maybe_unused)
 {
 
-    if (!host || host->aclk_config)
+    if (!host || host->aclk_host_config)
         return;
 
-    struct aclk_sync_cfg_t *wc = callocz(1, sizeof(struct aclk_sync_cfg_t));
+    struct aclk_sync_cfg_t *aclk_host_config = callocz(1, sizeof(struct aclk_sync_cfg_t));
     if (node_id && !uuid_is_null(*node_id))
-        uuid_unparse_lower(*node_id, wc->node_id);
+        uuid_unparse_lower(*node_id, aclk_host_config->node_id);
 
-    host->aclk_config = wc;
-    if (node_id && UUIDiszero(host->node_id)) {
-        uuid_copy(host->node_id.uuid, *node_id);
+    struct aclk_sync_cfg_t *expected = NULL;
+    if (__atomic_compare_exchange_n(&host->aclk_host_config, &expected, aclk_host_config, false, __ATOMIC_RELAXED, __ATOMIC_RELAXED)) {
+        if (node_id && UUIDiszero(host->node_id))
+            uuid_copy(host->node_id.uuid, *node_id);
+    }
+    else {
+        freez(aclk_host_config);
+        return;
     }
 
-    wc->host = host;
-    wc->stream_alerts = false;
+    aclk_host_config->host = host;
+    aclk_host_config->stream_alerts = false;
     time_t now = now_realtime_sec();
-    wc->node_info_send_time = (host == localhost || NULL == localhost) ? now - 25 : now;
-}
-
-void destroy_aclk_config(RRDHOST *host)
-{
-    if (!host || !host->aclk_config)
-        return;
-
-    freez(host->aclk_config);
-    host->aclk_config = NULL;
+    aclk_host_config->node_info_send_time = (host == localhost || NULL == localhost) ? now - 25 : now;
 }
 
 #define SQL_FETCH_ALL_HOSTS                                                                                            \
@@ -1003,22 +1051,24 @@ void aclk_synchronization_init(void)
     nd_log_daemon(NDLP_INFO, "ACLK sync initialization completed");
 }
 
-static inline void queue_aclk_sync_cmd(enum aclk_database_opcode opcode, const void *param0, const void *param1)
+static inline bool queue_aclk_sync_cmd(enum aclk_database_opcode opcode, const void *param0, const void *param1)
 {
     struct aclk_database_cmd cmd;
     cmd.opcode = opcode;
     cmd.param[0] = (void *) param0;
     cmd.param[1] = (void *) param1;
-    aclk_database_enq_cmd(&cmd);
+    return aclk_database_enq_cmd(&cmd);
 }
 
 void aclk_synchronization_shutdown(void)
 {
     // Send shutdown command, not that the completion is initialized
     // on init and still valid
-    queue_aclk_sync_cmd(ACLK_SYNC_SHUTDOWN, NULL, NULL);
+    aclk_mqtt_client_reset();
+
+    if (queue_aclk_sync_cmd(ACLK_SYNC_SHUTDOWN, NULL, NULL))
+        completion_wait_for(&aclk_sync_config.start_stop_complete);
 
-    completion_wait_for(&aclk_sync_config.start_stop_complete);
     completion_destroy(&aclk_sync_config.start_stop_complete);
     int rc = uv_thread_join(&aclk_sync_config.thread);
     if (rc)
@@ -1041,7 +1091,7 @@ void aclk_execute_query(aclk_query_t query)
     if (unlikely(!query))
         return;
 
-    queue_aclk_sync_cmd(ACLK_QUERY_EXECUTE, query, NULL);
+    (void) queue_aclk_sync_cmd(ACLK_QUERY_EXECUTE, query, NULL);
 }
 
 void aclk_add_job(aclk_query_t query)
@@ -1049,12 +1099,24 @@ void aclk_add_job(aclk_query_t query)
     if (unlikely(!query))
         return;
 
-    queue_aclk_sync_cmd(ACLK_QUERY_BATCH_ADD, query, NULL);
+    (void) queue_aclk_sync_cmd(ACLK_QUERY_BATCH_ADD, query, NULL);
 }
 
-void aclk_query_init(mqtt_wss_client client)
+void aclk_mqtt_client_set(mqtt_wss_client client)
 {
-    queue_aclk_sync_cmd(ACLK_MQTT_WSS_CLIENT, client, NULL);
+    (void) queue_aclk_sync_cmd(ACLK_MQTT_WSS_CLIENT_SET, client, NULL);
+}
+
+void aclk_mqtt_client_reset()
+{
+    if (!__atomic_load_n(&aclk_sync_config.client, __ATOMIC_RELAXED))
+        return;
+
+    struct completion compl;
+    completion_init(&compl);
+    if (queue_aclk_sync_cmd(ACLK_MQTT_WSS_CLIENT_RESET, &compl, NULL))
+        completion_wait_for(&compl);
+    completion_destroy(&compl);
 }
 
 void schedule_node_state_update(RRDHOST *host, uint64_t delay)
@@ -1062,12 +1124,40 @@ void schedule_node_state_update(RRDHOST *host, uint64_t delay)
     if (unlikely(!host))
         return;
 
-    queue_aclk_sync_cmd(ACLK_DATABASE_NODE_STATE, host, (void *)(uintptr_t)delay);
+    (void) queue_aclk_sync_cmd(ACLK_DATABASE_NODE_STATE, host, (void *)(uintptr_t)delay);
 }
 
 void unregister_node(const char *machine_guid)
 {
     if (unlikely(!machine_guid))
         return;
-    queue_aclk_sync_cmd(ACLK_DATABASE_NODE_UNREGISTER, strdupz(machine_guid), NULL);
+
+    (void) queue_aclk_sync_cmd(ACLK_DATABASE_NODE_UNREGISTER, strdupz(machine_guid), NULL);
+}
+
+void destroy_aclk_config(RRDHOST *host)
+{
+    if (!host)
+        return;
+
+    struct aclk_sync_cfg_t *aclk_host_config = __atomic_load_n(&host->aclk_host_config, __ATOMIC_RELAXED);
+    if (!aclk_host_config)
+        return;
+
+    if(likely(__atomic_load_n(&aclk_sync_config.initialized, __ATOMIC_RELAXED))) {
+        struct completion compl;
+        completion_init(&compl);
+
+        if (queue_aclk_sync_cmd(ACLK_CANCEL_NODE_UPDATE_TIMER, (void *)host, (void *)&compl))
+            completion_wait_for(&compl);
+        completion_destroy(&compl);
+    }
+
+    struct aclk_sync_cfg_t *old_aclk_host_config = __atomic_exchange_n(&host->aclk_host_config, NULL, __ATOMIC_RELAXED);
+    freez(old_aclk_host_config);
+}
+
+void aclk_queue_node_info(RRDHOST *host, bool immediate)
+{
+    (void) queue_aclk_sync_cmd(ACLK_QUEUE_NODE_INFO, (void *)host, (void *)(uintptr_t)immediate);
 }
