@@ -25,13 +25,13 @@ DICTIONARY *collectors_from_charts(RRDHOST *host, DICTIONARY *dict) {
 
 static void build_node_collectors(RRDHOST *host)
 {
-    struct aclk_sync_cfg_t *wc = host->aclk_config;
+    struct aclk_sync_cfg_t *aclk_host_config = host->aclk_host_config;
 
     struct update_node_collectors upd_node_collectors;
     DICTIONARY *dict = dictionary_create(DICT_OPTION_SINGLE_THREADED);
 
     CLAIM_ID claim_id = claim_id_get();
-    upd_node_collectors.node_id = wc->node_id;
+    upd_node_collectors.node_id = aclk_host_config->node_id;
     upd_node_collectors.claim_id = claim_id_is_set(claim_id) ? claim_id.str : NULL;
 
     upd_node_collectors.node_collectors = collectors_from_charts(host, dict);
@@ -41,19 +41,19 @@ static void build_node_collectors(RRDHOST *host)
 
     nd_log(NDLS_ACCESS, NDLP_DEBUG,
            "ACLK RES [%s (%s)]: NODE COLLECTORS SENT",
-           wc->node_id, rrdhost_hostname(host));
+        aclk_host_config->node_id, rrdhost_hostname(host));
 }
 
 static void build_node_info(RRDHOST *host)
 {
     struct update_node_info node_info;
 
-    struct aclk_sync_cfg_t *wc = host->aclk_config;
+    struct aclk_sync_cfg_t *aclk_host_config = host->aclk_host_config;
 
     CLAIM_ID claim_id = claim_id_get();
 
     rrd_rdlock();
-    node_info.node_id = wc->node_id;
+    node_info.node_id = aclk_host_config->node_id;
     node_info.claim_id = claim_id_is_set(claim_id) ? claim_id.str : NULL;
     node_info.machine_guid = host->machine_guid;
     node_info.child = (host != localhost);
@@ -85,7 +85,7 @@ static void build_node_info(RRDHOST *host)
         NDLS_ACCESS,
         NDLP_DEBUG,
         "ACLK RES [%s (%s)]: NODE INFO SENT for guid [%s] (%s)",
-        wc->node_id,
+        aclk_host_config->node_id,
         rrdhost_hostname(host),
         host->machine_guid,
         host == localhost ? "parent" : "child");
@@ -94,7 +94,7 @@ static void build_node_info(RRDHOST *host)
     freez(node_info.node_instance_capabilities);
     freez(host_version);
 
-    wc->node_collectors_send = now_realtime_sec();
+    aclk_host_config->node_collectors_send = now_realtime_sec();
 }
 
 void aclk_check_node_info_and_collectors(void)
@@ -121,8 +121,8 @@ void aclk_check_node_info_and_collectors(void)
     time_t now = now_realtime_sec();
     dfe_start_reentrant(rrdhost_root_index, host)
     {
-        struct aclk_sync_cfg_t *wc = host->aclk_config;
-        if (unlikely(!wc))
+        struct aclk_sync_cfg_t *aclk_host_config = host->aclk_host_config;
+        if (unlikely(!aclk_host_config))
             continue;
 
         if (unlikely(rrdhost_flag_check(host, RRDHOST_FLAG_PENDING_CONTEXT_LOAD))) {
@@ -132,7 +132,7 @@ void aclk_check_node_info_and_collectors(void)
             continue;
         }
 
-        if (!wc->node_info_send_time && !wc->node_collectors_send)
+        if (!aclk_host_config->node_info_send_time && !aclk_host_config->node_collectors_send)
             continue;
 
         if (unlikely(rrdhost_receiver_replicating_charts(host))) {
@@ -156,22 +156,24 @@ void aclk_check_node_info_and_collectors(void)
 
         bool pp_queue_empty = !(host->rrdctx.pp_queue && dictionary_entries(host->rrdctx.pp_queue));
 
-        if (!pp_queue_empty && (wc->node_info_send_time || wc->node_collectors_send)) {
+        if (!pp_queue_empty && (aclk_host_config->node_info_send_time || aclk_host_config->node_collectors_send)) {
             context_pp++;
             context_pp_host = host->hostname;
         }
 
-        if (pp_queue_empty && wc->node_info_send_time && wc->node_info_send_time + 30 < now) {
-            wc->node_info_send_time = 0;
+        if (pp_queue_empty && aclk_host_config->node_info_send_time &&
+            aclk_host_config->node_info_send_time + 30 < now) {
+            aclk_host_config->node_info_send_time = 0;
             build_node_info(host);
             schedule_node_state_update(host, 10000);
             internal_error(true, "ACLK SYNC: Sending node info for %s", rrdhost_hostname(host));
         }
 
-        if (pp_queue_empty && wc->node_collectors_send && wc->node_collectors_send + 30 < now) {
+        if (pp_queue_empty && aclk_host_config->node_collectors_send &&
+            aclk_host_config->node_collectors_send + 30 < now) {
             build_node_collectors(host);
             internal_error(true, "ACLK SYNC: Sending collectors for %s", rrdhost_hostname(host));
-            wc->node_collectors_send = 0;
+            aclk_host_config->node_collectors_send = 0;
         }
     }
     dfe_done(host);
