@@ -19,6 +19,8 @@ const (
 	prioNetIfaceAdminStatus
 	prioNetIfaceOperStatus
 	prioSysUptime
+
+	priosnmp
 )
 
 var netIfaceChartsTmpl = module.Charts{
@@ -32,6 +34,20 @@ var netIfaceChartsTmpl = module.Charts{
 	netIfaceOperStatusChartTmpl.Copy(),
 }
 
+var (
+	snmpChartTemplate = module.Chart{
+		ID:       "%s",
+		Title:    "%s",
+		Units:    "%s",
+		Fam:      "%s",
+		Ctx:      "snmp.%s",
+		Priority: priosnmp,
+		Dims: module.Dims{
+			{ID: "%s", Name: "%s"},
+		},
+	}
+)
+
 var (
 	netIfaceTrafficChartTmpl = module.Chart{
 		ID:       "snmp_device_net_iface_%s_traffic",
@@ -178,6 +194,36 @@ func (c *Collector) addNetIfaceCharts(iface *netInterface) {
 	}
 }
 
+func (c *Collector) addSNMPChart(processedMetric processedMetric) {
+	if processedMetric.tableName == "" {
+		chart := snmpChartTemplate.Copy()
+
+		chart.ID = fmt.Sprintf(chart.ID, processedMetric.name)
+		chart.Title = fmt.Sprintf(chart.Title, processedMetric.name)
+		chart.Units = fmt.Sprintf(chart.Units, "TBD unit")
+		chart.Ctx = fmt.Sprintf(chart.Ctx, processedMetric.name)
+		chart.Fam = fmt.Sprintf(chart.Fam, processedMetric.name)
+
+		for _, dim := range chart.Dims {
+			dim.ID = fmt.Sprintf(dim.ID, processedMetric.name)
+			dim.Name = fmt.Sprintf(dim.Name, processedMetric.name)
+		}
+
+		if err := c.Charts().Add(chart); err != nil {
+			c.Warning(err)
+		}
+	}
+}
+
+func (c *Collector) removeSNMPChart(name string) {
+	for _, chart := range *c.Charts() {
+		if chart.ID == name {
+			chart.MarkRemove()
+			chart.MarkNotCreated()
+		}
+	}
+}
+
 func (c *Collector) removeNetIfaceCharts(iface *netInterface) {
 	px := fmt.Sprintf("snmp_device_net_iface_%s_", cleanIfaceName(iface.ifName))
 	for _, chart := range *c.Charts() {
