@@ -152,6 +152,7 @@ void health_plugin_init(void) {
 
     health_globals.initialization.done = true;
 
+    health_alarm_entry_aral_init();
     health_init_prototypes();
     health_load_config_defaults();
 
@@ -166,7 +167,20 @@ cleanup:
 }
 
 void health_plugin_destroy(void) {
-    ;
+    if(!health_globals.initialization.done)
+        return;
+
+    spinlock_lock(&health_globals.initialization.spinlock);
+
+    // Clean up health prototypes dictionary
+    if(health_globals.prototypes.dict) {
+        dictionary_destroy(health_globals.prototypes.dict);
+        health_globals.prototypes.dict = NULL;
+    }
+
+    health_globals.initialization.done = false;
+
+    spinlock_unlock(&health_globals.initialization.spinlock);
 }
 
 void health_plugin_reload(void) {
