@@ -283,8 +283,8 @@ static void health_event_loop_for_host(RRDHOST *host, bool apply_hibernation_del
 
     worker_is_busy(WORKER_HEALTH_JOB_HOST_LOCK);
     {
-        struct aclk_sync_cfg_t *wc = host->aclk_config;
-        if (wc && wc->send_snapshot == 2)
+        struct aclk_sync_cfg_t *aclk_host_config = __atomic_load_n(&host->aclk_host_config, __ATOMIC_RELAXED);
+        if (aclk_host_config && aclk_host_config->send_snapshot == 2)
             return;
     }
 
@@ -634,9 +634,9 @@ static void health_event_loop_for_host(RRDHOST *host, bool apply_hibernation_del
         commit_alert_transitions(host);
 
     if (!__atomic_load_n(&host->health.pending_transitions, __ATOMIC_RELAXED)) {
-        struct aclk_sync_cfg_t *wc = host->aclk_config;
-        if (wc && wc->send_snapshot == 1) {
-            wc->send_snapshot = 2;
+        struct aclk_sync_cfg_t *aclk_host_config = __atomic_load_n(&host->aclk_host_config, __ATOMIC_RELAXED);
+        if (aclk_host_config && aclk_host_config->send_snapshot == 1) {
+            aclk_host_config->send_snapshot = 2;
             rrdhost_flag_set(host, RRDHOST_FLAG_ACLK_STREAM_ALERTS);
         } else {
             worker_is_busy(WORKER_HEALTH_JOB_ALARM_LOG_QUEUE);
