@@ -364,19 +364,6 @@ static void rrdcalc_rrdhost_react_callback(const DICTIONARY_ITEM *item __maybe_u
 // ----------------------------------------------------------------------------
 // RRDCALC rrdhost index management - destructor
 
-static void rrdcalc_free_internals(RRDCALC *rc) {
-    if(unlikely(!rc)) return;
-
-    rrd_alert_match_cleanup(&rc->match);
-    rrd_alert_config_cleanup(&rc->config);
-
-    string_freez(rc->key);
-    string_freez(rc->chart);
-
-    string_freez(rc->info);
-    string_freez(rc->summary);
-}
-
 static __thread bool thread_having_ll_wrlock = false;
 
 static void rrdcalc_rrdhost_delete_callback(const DICTIONARY_ITEM *item __maybe_unused, void *rrdcalc, void *rrdhost __maybe_unused) {
@@ -388,7 +375,16 @@ static void rrdcalc_rrdhost_delete_callback(const DICTIONARY_ITEM *item __maybe_
     // any destruction actions that require other locks
     // have to be placed in rrdcalc_del(), because the object is actually locked for deletion
 
-    rrdcalc_free_internals(rc);
+    rrd_alert_match_cleanup(&rc->match);
+    rrd_alert_config_cleanup(&rc->config);
+
+    string_freez(rc->key);
+    string_freez(rc->chart);
+
+    string_freez(rc->info);
+    string_freez(rc->summary);
+
+    memset(rc, 0, sizeof(*rc));
 }
 
 // ----------------------------------------------------------------------------
@@ -491,6 +487,8 @@ void rrd_alert_match_cleanup(struct rrd_alert_match *am) {
 
     string_freez(am->chart_labels);
     pattern_array_free(am->chart_labels_pattern);
+
+    memset(am, 0, sizeof(*am));
 }
 
 void rrd_alert_config_cleanup(struct rrd_alert_config *ac) {
@@ -513,4 +511,6 @@ void rrd_alert_config_cleanup(struct rrd_alert_config *ac) {
     expression_free(ac->calculation);
     expression_free(ac->warning);
     expression_free(ac->critical);
+
+    memset(ac, 0, sizeof(*ac));
 }
