@@ -160,6 +160,9 @@ void libjudy_malloc_init(void) {
     // IMPORTANT: this is not called on external plugins
     // the allocator should run even if this is not called
 
+    (void)jemalloc_initialized;
+    (void)jemalloc_arena_index;
+
 #ifdef HAVE_JEMALLOC_ARENA_API
     jemalloc_init();
     if(!jemalloc_initialized)
