@@ -65,7 +65,13 @@ void stream_receiver_log_payload(struct receiver_state *rpt, const char *payload
 }
 #endif
 
-static void stream_receiver_remove(struct stream_thread *sth, struct receiver_state *rpt, STREAM_HANDSHAKE reason);
+// help the IDE identify use after free
+#define stream_receiver_remove(sth, rpt, reason) do {           \
+        stream_receiver_remove_internal(sth, rpt, reason);      \
+        (rpt) = NULL;                                           \
+} while(0)
+
+static void stream_receiver_remove_internal(struct stream_thread *sth, struct receiver_state *rpt, STREAM_HANDSHAKE reason);
 
 // When a child disconnects this is the maximum we will wait
 // before we update the cloud that the child is offline
@@ -110,7 +116,8 @@ static bool stream_receiver_log_transport(BUFFER *wb, void *ptr) {
 
 // --------------------------------------------------------------------------------------------------------------------
 
-static inline ssize_t write_stream(struct receiver_state *r, char* buffer, size_t size) {
+ALWAYS_INLINE
+static ssize_t write_stream(struct receiver_state *r, char* buffer, size_t size) {
     if(unlikely(!size)) {
         internal_error(true, "%s() asked to read zero bytes", __FUNCTION__);
         errno_clear();
@@ -132,7 +139,8 @@ static inline ssize_t write_stream(struct receiver_state *r, char* buffer, size_
     return bytes_written;
 }
 
-static inline ssize_t read_stream(struct receiver_state *r, char* buffer, size_t size) {
+ALWAYS_INLINE
+static ssize_t read_stream(struct receiver_state *r, char* buffer, size_t size) {
     if(unlikely(!size)) {
         internal_error(true, "%s() asked to read zero bytes", __FUNCTION__);
         errno_clear();
@@ -156,7 +164,8 @@ static inline ssize_t read_stream(struct receiver_state *r, char* buffer, size_t
 
 // --------------------------------------------------------------------------------------------------------------------
 
-static inline ssize_t receiver_read_uncompressed(struct receiver_state *r) {
+ALWAYS_INLINE
+static ssize_t receiver_read_uncompressed(struct receiver_state *r) {
     internal_fatal(r->thread.uncompressed.read_buffer[r->thread.uncompressed.read_len] != '\0',
                    "%s: read_buffer does not start with zero #2", __FUNCTION__ );
 
@@ -192,7 +201,8 @@ static inline void receiver_move_compressed(struct receiver_state *r) {
     }
 }
 
-static inline decompressor_status_t receiver_feed_decompressor(struct receiver_state *r) {
+ALWAYS_INLINE_HOT_FLATTEN
+static decompressor_status_t receiver_feed_decompressor(struct receiver_state *r) {
     char *buf = r->thread.compressed.buf;
     size_t start = r->thread.compressed.start;
     size_t signature_size = r->thread.compressed.decompressor.signature_size;
@@ -248,7 +258,8 @@ static inline decompressor_status_t receiver_feed_decompressor(struct receiver_s
     return DECOMPRESS_OK;
 }
 
-static inline decompressor_status_t receiver_get_decompressed(struct receiver_state *r) {
+ALWAYS_INLINE_HOT_FLATTEN
+static decompressor_status_t receiver_get_decompressed(struct receiver_state *r) {
     if (unlikely(!stream_decompressed_bytes_in_buffer(&r->thread.compressed.decompressor)))
         return DECOMPRESS_NEED_MORE_DATA;
 
@@ -272,7 +283,8 @@ static inline decompressor_status_t receiver_get_decompressed(struct receiver_st
     return DECOMPRESS_OK;
 }
 
-static inline ssize_t receiver_read_compressed(struct receiver_state *r) {
+ALWAYS_INLINE_HOT_FLATTEN
+static ssize_t receiver_read_compressed(struct receiver_state *r) {
 
     internal_fatal(r->thread.uncompressed.read_buffer[r->thread.uncompressed.read_len] != '\0',
                    "%s: read_buffer does not start with zero #2", __FUNCTION__ );
@@ -298,7 +310,8 @@ static STREAM_HANDSHAKE receiver_set_exit_reason(struct receiver_state *rpt, STR
     return rpt->exit.reason;
 }
 
-static inline bool receiver_should_stop(struct receiver_state *rpt) {
+ALWAYS_INLINE
+static bool receiver_should_stop(struct receiver_state *rpt) {
     if(unlikely(__atomic_load_n(&rpt->exit.shutdown, __ATOMIC_ACQUIRE))) {
         receiver_set_exit_reason(rpt, STREAM_HANDSHAKE_DISCONNECT_SIGNALED_TO_STOP, false);
         return true;
@@ -309,6 +322,7 @@ static inline bool receiver_should_stop(struct receiver_state *rpt) {
 
 // --------------------------------------------------------------------------------------------------------------------
 
+ALWAYS_INLINE
 void stream_receiver_handle_op(struct stream_thread *sth, struct receiver_state *rpt, struct stream_opcode *msg) {
     ND_LOG_STACK lgs[] = {
         ND_LOG_FIELD_STR(NDF_NIDL_NODE, rpt->host->hostname),
@@ -427,23 +441,6 @@ void stream_receiver_move_to_running_unsafe(struct stream_thread *sth, struct re
                "Failed to add receiver socket to nd_poll()",
                sth->id, rrdhost_hostname(rpt->host), rpt->remote_ip, rpt->remote_port);
 
-    // put the client IP and port into the buffers used by plugins.d
-    {
-        char buf[CONFIG_MAX_NAME];
-        snprintfz(buf, sizeof(buf),  "[%s]:%s", rpt->remote_ip, rpt->remote_port);
-        string_freez(rpt->thread.cd.id);
-        rpt->thread.cd.id = string_strdupz(buf);
-
-        string_freez(rpt->thread.cd.filename);
-        rpt->thread.cd.filename = string_strdupz(buf);
-
-        string_freez(rpt->thread.cd.fullfilename);
-        rpt->thread.cd.fullfilename = string_strdupz(buf);
-
-        string_freez(rpt->thread.cd.cmd);
-        rpt->thread.cd.cmd = string_strdupz(buf);
-    }
-
     rpt->thread.compressed.start = 0;
     rpt->thread.compressed.used = 0;
     rpt->thread.compressed.enabled = stream_decompression_initialize(rpt);
@@ -458,15 +455,25 @@ void stream_receiver_move_to_running_unsafe(struct stream_thread *sth, struct re
 
     PARSER *parser = NULL;
     {
-        rpt->thread.cd = (struct plugind){
-            .update_every = nd_profile.update_every,
-            .unsafe = {
-                .spinlock = SPINLOCK_INITIALIZER,
-                .running = true,
-                .enabled = true,
-            },
-            .started_t = now_realtime_sec(),
-        };
+        char buf[CONFIG_MAX_NAME];
+        snprintfz(buf, sizeof(buf),  "[%s]:%s", rpt->remote_ip, rpt->remote_port);
+        string_freez(rpt->thread.cd.id);
+        rpt->thread.cd.id = string_strdupz(buf);
+
+        string_freez(rpt->thread.cd.filename);
+        rpt->thread.cd.filename = NULL;
+
+        string_freez(rpt->thread.cd.fullfilename);
+        rpt->thread.cd.fullfilename = NULL;
+
+        string_freez(rpt->thread.cd.cmd);
+        rpt->thread.cd.cmd = NULL;
+
+        rpt->thread.cd.update_every = (int)nd_profile.update_every;
+        spinlock_init(&rpt->thread.cd.unsafe.spinlock);
+        rpt->thread.cd.unsafe.running = true;
+        rpt->thread.cd.unsafe.enabled = true;
+        rpt->thread.cd.started_t = now_realtime_sec();
 
         PARSER_USER_OBJECT user = {
             .enabled = plugin_is_enabled(&rpt->thread.cd),
@@ -515,7 +522,7 @@ void stream_receiver_move_entire_queue_to_running_unsafe(struct stream_thread *s
     }
 }
 
-static void stream_receiver_remove(struct stream_thread *sth, struct receiver_state *rpt, STREAM_HANDSHAKE reason) {
+static void stream_receiver_remove_internal(struct stream_thread *sth, struct receiver_state *rpt, STREAM_HANDSHAKE reason) {
     internal_fatal(sth->tid != gettid_cached(), "Function %s() should only be used by the dispatcher thread", __FUNCTION__ );
 
     receiver_set_exit_reason(rpt, reason, false);
@@ -532,7 +539,9 @@ static void stream_receiver_remove(struct stream_thread *sth, struct receiver_st
     ND_LOG_STACK_PUSH(lgs);
 
     PARSER *parser = __atomic_load_n(&rpt->thread.parser, __ATOMIC_RELAXED);
-    size_t count = parser ? parser->user.data_collections_count : 0;
+    size_t count = 0;
+    if(parser)
+        count = parser->user.data_collections_count;
 
     errno_clear();
     nd_log(NDLS_DAEMON, NDLP_ERR,
@@ -800,8 +809,9 @@ bool stream_receiver_receive_data(struct stream_thread *sth, struct receiver_sta
     };
     ND_LOG_STACK_PUSH(lgs);
 
+    size_t count = 1; // how many reads to do per host, before moving to the next host
     EVLOOP_STATUS status = EVLOOP_STATUS_CONTINUE;
-    while(status == EVLOOP_STATUS_CONTINUE) {
+    while(status == EVLOOP_STATUS_CONTINUE && count-- > 0) {
         bool removed = false;
         ssize_t rc = stream_receive_and_process(sth, rpt, parser, now_ut, &removed);
         if(unlikely(removed))
@@ -841,6 +851,7 @@ bool stream_receiver_receive_data(struct stream_thread *sth, struct receiver_sta
                    stream_handshake_error_to_string(reason), rpt->sock.fd);
 
             stream_receiver_remove(sth, rpt, reason);
+            break;
         }
         else if(status == EVLOOP_STATUS_CONTINUE && process_opcodes && stream_thread_process_opcodes(sth, &rpt->thread.meta))
             status = EVLOOP_STATUS_OPCODE_ON_ME;
@@ -953,12 +964,18 @@ void stream_receiver_check_all_nodes_from_poll(struct stream_thread *sth, usec_t
             continue;
         }
 
-        rpt->thread.wanted = ND_POLL_READ | (stats.bytes_outstanding ? ND_POLL_WRITE : 0);
-        if(!nd_poll_upd(sth->run.ndpl, rpt->sock.fd, rpt->thread.wanted))
-            nd_log(NDLS_DAEMON, NDLP_ERR,
-                   "STREAM RCV[%zu] '%s' [from %s]: failed to update nd_poll().",
-                   sth->id, rrdhost_hostname(rpt->host), rpt->remote_ip);
+        nd_poll_event_t wanted = ND_POLL_READ | (stats.bytes_outstanding ? ND_POLL_WRITE : 0);
+        if(unlikely(rpt->thread.wanted != wanted)) {
+//            nd_log(NDLS_DAEMON, NDLP_DEBUG,
+//                   "STREAM RCV[%zu] '%s' [from %s]: nd_poll() wanted events mismatch.",
+//                   sth->id, rrdhost_hostname(rpt->host), rpt->remote_ip);
 
+            rpt->thread.wanted = wanted;
+            if(!nd_poll_upd(sth->run.ndpl, rpt->sock.fd, rpt->thread.wanted))
+                nd_log(NDLS_DAEMON, NDLP_ERR,
+                       "STREAM RCV[%zu] '%s' [from %s]: failed to update nd_poll().",
+                       sth->id, rrdhost_hostname(rpt->host), rpt->remote_ip);
+        }
     }
 }
 
@@ -1040,6 +1057,7 @@ void stream_receiver_replication_check_from_poll(struct stream_thread *sth, usec
                    __atomic_load_n(&host->stream.rcv.status.replication.counter_in, __ATOMIC_RELAXED));
 
             stream_receiver_remove(sth, rpt, STREAM_HANDSHAKE_DISCONNECT_REPLICATION_STALLED);
+            continue;
         }
 
         rpt->replication.last_checked_ut = rpt->replication.last_progress_ut;
@@ -1102,6 +1120,7 @@ bool rrdhost_set_receiver(RRDHOST *host, struct receiver_state *rpt) {
         host->receiver = rpt;
         rpt->host = host;
 
+        host->stream.rcv.status.reason = (STREAM_HANDSHAKE)rpt->capabilities;
         rpt->exit.reason = 0;
         __atomic_store_n(&rpt->exit.shutdown, false, __ATOMIC_RELEASE);
         host->stream.rcv.status.last_connected = now_realtime_sec();
@@ -1132,7 +1151,7 @@ bool rrdhost_set_receiver(RRDHOST *host, struct receiver_state *rpt) {
         rrdhost_flag_set(rpt->host, RRDHOST_FLAG_COLLECTOR_ONLINE);
         aclk_queue_node_info(rpt->host, true);
 
-        rrdhost_stream_parents_reset(host, STREAM_HANDSHAKE_SP_PREPARING);
+        stream_parents_host_reset(host, STREAM_HANDSHAKE_SP_PREPARING);
 
         set_this = true;
     }
@@ -1175,7 +1194,7 @@ void rrdhost_clear_receiver(struct receiver_state *rpt, STREAM_HANDSHAKE reason)
                 if (rpt->config.health.enabled)
                     rrdcalc_child_disconnected(host);
 
-                rrdhost_stream_parents_reset(host, reason);
+                stream_parents_host_reset(host, reason);
             }
             rrdhost_receiver_lock(host);
 
@@ -1184,14 +1203,14 @@ void rrdhost_clear_receiver(struct receiver_state *rpt, STREAM_HANDSHAKE reason)
             stream_receiver_replication_reset(host);
             streaming_receiver_disconnected();
 
-            host->receiver->exit.reason = 0;
-            __atomic_store_n(&host->receiver->exit.shutdown, false, __ATOMIC_RELEASE);
+            host->stream.rcv.status.reason = rpt->exit.reason;
+            rpt->exit.reason = 0;
+            __atomic_store_n(&rpt->exit.shutdown, false, __ATOMIC_RELEASE);
             host->stream.rcv.status.check_obsolete = false;
             host->stream.rcv.status.last_connected = 0;
             host->stream.rcv.status.last_disconnected = now_realtime_sec();
             host->health.enabled = false;
 
-            host->stream.rcv.status.exit_reason = rpt->exit.reason;
             rrdhost_flag_set(host, RRDHOST_FLAG_ORPHAN);
             host->receiver = NULL;
         }
