@@ -330,7 +330,7 @@ bool web_client_bearer_token_auth(struct web_client *w, const char *v) {
 
 void bearer_tokens_init(void) {
     netdata_is_protected_by_bearer =
-        config_get_boolean(CONFIG_SECTION_WEB, "bearer token protection", netdata_is_protected_by_bearer);
+        inicfg_get_boolean(&netdata_config, CONFIG_SECTION_WEB, "bearer token protection", netdata_is_protected_by_bearer);
 
     netdata_authorized_bearers = dictionary_create_advanced(
         DICT_OPTION_DONT_OVERWRITE_VALUE | DICT_OPTION_FIXED_SIZE,
